@@ -62,7 +62,7 @@ Agreement.
 
 """
 
-from copy import copy
+from copy import copy, deepcopy
 
 SENTINEL = object()
 
@@ -95,7 +95,7 @@ class LRUCache:
         cache = LRUCache(self.max_size)
         cache.full = self.full
         cache.cache = copy(self.cache)
-        cache.root = copy(self.root)
+        cache.root = deepcopy(self.root)
         return cache
 
     def set(self, key, value):
@@ -167,7 +167,15 @@ class LRUCache:
     def get_all(self):
         nodes = []
         node = self.root[NEXT]
-        while node is not self.root:
+
+        # To ensure the loop always terminates we iterate to the maximum
+        # size of the LRU cache.
+        for _ in range(self.max_size):
+            # The cache may not be full. We exit early if we've wrapped
+            # around to the head.
+            if node is self.root:
+                break
             nodes.append((node[KEY], node[VALUE]))
             node = node[NEXT]
+
         return nodes
